@@ -111,11 +111,11 @@ class Logger:
         """
 
         self.min_loglevel: LogLevel = min_loglevel
-        if self.min_loglevel is None:
+        if min_loglevel is None:
             self.min_loglevel: LogLevel = LogLevel.INFO
 
         self.max_loglevel: LogLevel = max_loglevel
-        if self.max_loglevel is None:
+        if max_loglevel is None:
             self.max_loglevel: LogLevel = LogLevel.INFO
 
         self.name: str = name
